@@ -2,15 +2,16 @@
 #                                                                             #
 #  GENERALIZED NETWORK-BASED DIMENSIONALITY REDUCTION AND ANALYSIS (GNDA)     #
 #                                                                             #
-#  Written by: Zsolt T. Kosztyan*, Marcell T. Kurbucz, Attila I. Katona       #
+#  Written by: Zsolt T. Kosztyan*, Marcell T. Kurbucz, Attila I. Katona,      #
+#              Zahid Khan                                                     #
 #              *Department of Quantitative Methods                            #
 #              University of Pannonia, Hungary                                #
 #              kosztyan.zsolt@gtk.uni-pannon.hu                               #
 #                                                                             #
-# Last modified: February 2023                                                #
+# Last modified: February 2024                                                #
 #-----------------------------------------------------------------------------#
+######## MATRIX-BASED DISTANCE CORRELATION ########
 #' @export
-
 dCor<-function(x,y=NULL){
   if (!requireNamespace("energy", quietly = TRUE)) {
     stop(
@@ -18,6 +19,14 @@ dCor<-function(x,y=NULL){
       call. = FALSE
     )
   }
+  if (is.data.frame(x)|is.matrix(x)){
+    if (min(dim(x))>1){
+      if (!is.null(y)){
+        warning("x is a matrix or a data.frame with at least two columns, y is neglected.")
+      }
+      y<-NULL
+    }
+  }
   if (is.null(y)){
     if (is.data.frame(x)|is.matrix(x)){
       dC<-matrix(0,nrow=ncol(x),ncol=ncol(x))
@@ -31,8 +40,8 @@ dCor<-function(x,y=NULL){
       dCor<-dC
       dCor
     }else{
-      stop("Error: x must be a matrix or a dataframe!")
       dCor<-NULL
+      stop("Error: x must be a matrix or a dataframe!")
     }
   }else{
     dCor<-energy::dcor(x,y)
