@@ -8,14 +8,14 @@
 #              University of Pannonia, Hungary                                #
 #              kosztyan.zsolt@gtk.uni-pannon.hu                               #
 #                                                                             #
-# Last modified: February 2024                                                #
+# Last modified: February 2025                                                #
 #-----------------------------------------------------------------------------#
 #### GENERALIZED NETWORK-BASED DIMENSIONALITY REDUCTION AND ANALYSIS (GNDA) ###
 #' @export
 ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
-              null_modell_type=4,mod_mode=6,min_evalue=0,
+              null_model_type=4,mod_mode=6,min_evalue=0,
               min_communality=0,com_communalities=0,use_rotation=FALSE,
-              rotation="oblimin"){
+              rotation="oblimin",weight=NULL,seed=NULL){
 
   cl<-match.call()
   if (!requireNamespace("energy", quietly = TRUE)) {
@@ -54,6 +54,25 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
       call. = FALSE
     )
   }
+  if (!is.numeric(as.matrix(r))) {
+    stop(
+      "The data should be numeric matrix or data.frame!",
+      call. = FALSE
+    )
+  }
+  if (!is.null(seed))
+  {
+    set.seed(seed)
+  }
+  if (is.null(weight)){
+    weight=rep(1,ncol(r))
+  }
+  r<-t(t(r)*weight)
+  weight[is.na(weight)]<-0
+  if (is.na(min_R)) {min_R<-0}
+  if (is.na(min_evalue)) {min_evalue<-0}
+  if (is.na(min_communality)) {min_communality<-0}
+  if (is.na(com_communalities)) {com_communalities<-0}
   DATA<-r
   X<-r
 
@@ -139,8 +158,9 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
                                                           mode = "undirected", weighted = TRUE, diag = FALSE)),
       "5"=igraph::cluster_walktrap(igraph::graph_from_adjacency_matrix(as.matrix(MTX),
                                                            mode = "undirected", weighted = TRUE, diag = FALSE)),
-      "6"=leidenAlg::leiden.community(igraph::graph_from_adjacency_matrix(as.matrix(MTX),
-                                                              mode = "directed", weighted = TRUE, diag = FALSE))
+      "6"=if (inherits(try(leidenAlg::leiden.community(igraph::graph_from_adjacency_matrix(as.matrix(MTX),mode = "undirected", weighted = TRUE, diag = FALSE)),silent = TRUE),"try-error"))
+      {igraph::cluster_leiden(igraph::graph_from_adjacency_matrix(as.matrix(MTX),mode = "undirected", weighted = TRUE, diag = FALSE),objective_function = "modularity")}
+      else{leidenAlg::leiden.community(igraph::graph_from_adjacency_matrix(as.matrix(MTX),mode = "undirected", weighted = TRUE, diag = FALSE))}
     )
   }else{
     modular=switch(
@@ -155,15 +175,14 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
                                                           mode = "directed", weighted = TRUE, diag = FALSE)),
       "5"=igraph::cluster_walktrap(igraph::graph_from_adjacency_matrix(as.matrix(MTX),
                                                            mode = "directed", weighted = TRUE, diag = FALSE)),
-      "6"=leidenAlg::leiden.community(igraph::graph_from_adjacency_matrix(as.matrix(MTX),
-                                                                      mode = "directed", weighted = TRUE, diag = FALSE))
+      "6"=if (inherits(try(leidenAlg::leiden.community(igraph::graph_from_adjacency_matrix(as.matrix(MTX),mode = "directed", weighted = TRUE, diag = FALSE)),silent = TRUE),"try-error"))
+      {igraph::cluster_leiden(igraph::as.undirected(igraph::graph_from_adjacency_matrix(as.matrix(MTX),mode = "directed", weighted = TRUE, diag = FALSE)),objective_function = "modularity")}
+      else{leidenAlg::leiden.community(igraph::graph_from_adjacency_matrix(as.matrix(MTX),mode = "directed", weighted = TRUE, diag = FALSE))}
     )
   }
 
   S<-as.numeric(modular$membership)
 
-  # igraph::sizes(modular)
-
   for (i in 1: max(S)){
     if (nrow(as.matrix(coords[S==i]))<min_comm){
       coords[S==i]<-0
@@ -210,13 +229,17 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
         weighted = TRUE, diag = FALSE))$vector)
     }
     if ((nrow(as.matrix(EVC[EVC>min_evalue]))>2)&(nrow(EVC)>2)){
-      L[,i]<-as.matrix(rowSums(r[,
-                                 Coordsi[EVC>min_evalue]] * EVC[EVC>min_evalue]))
+      L[,i]<-if (inherits(try(as.matrix(rowSums(r[,
+                                 Coordsi[EVC>min_evalue]] * EVC[EVC>min_evalue])),
+                              silent = TRUE),"try-error")) {as.matrix(rowSums(r[,
+                           Coordsi[EVC>min_evalue]] %*% EVC[EVC>min_evalue]))}
+      else{as.matrix(rowSums(r[,Coordsi[EVC>min_evalue]] * EVC[EVC>min_evalue]))}
       coords[Coordsi[EVC<=min_evalue]]<-0
       coords[Coordsi[EVC<=min_evalue]]<-0
       S[Coordsi[EVC<=min_evalue]]<-0
     }else{
-      L[,i]<-as.matrix(rowSums(r[,Coordsi] * EVC))
+      L[,i]<-if (inherits(try(as.matrix(rowSums(r[,Coordsi] * EVC)),silent = TRUE),"try-error"))
+        {as.matrix(rowSums(r[,Coordsi] %*% EVC))}else{as.matrix(rowSums(r[,Coordsi] * EVC))}
     }
     EVCs[[i]]=EVC[EVC>min_evalue]
     DATAs[[i]]=r[,S==M[i]];
@@ -280,10 +303,15 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
         EVC<-EVCs[[i]]
         EVC<-EVC[COM>min_communality]
         EVCs[[i]]<-EVC
-        L[,i]<-as.matrix(rowSums(r[,Coordsi[COM>min_communality]] * EVC))
+
+        L[,i]<-if (inherits(try(as.matrix(rowSums(r[,Coordsi[COM>min_communality]] * EVC)),silent = TRUE),"try-error"))
+        {as.matrix(rowSums(r[,Coordsi[COM>min_communality]] %*% EVC))}else{
+          as.matrix(rowSums(r[,Coordsi[COM>min_communality]] * EVC))
+        }
       }else{
         EVC<-EVCs[[i]]
-        L[,i]<-as.matrix(rowSums(r[,Coordsi] * EVC))
+        L[,i]<-if (inherits(try(as.matrix(rowSums(r[,Coordsi] * EVC)),silent = TRUE),"try-error"))
+        {as.matrix(rowSums(r[,Coordsi] %*% EVC))}else{as.matrix(rowSums(r[,Coordsi] * EVC))}
       }
     }
     if (ncol(L)>1 && use_rotation==TRUE){
@@ -374,6 +402,7 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
       }
       L[,i]<-result
     }
+    centers<-colMeans(L)
     if (ncol(L)>1 && use_rotation==TRUE){
       L<-psych::principal(L,nfactors = dim(L)[2],
                           rotate = rotation)$scores
@@ -419,10 +448,16 @@ ndr<-function(r,covar=FALSE,cor_method=1,cor_type=1,min_R=0,min_comm=2,Gamma=1,
   }
   P$n.obs<-nrow(DATA)
   P$R<-R
+  P$EVCs<-EVCs
+  P$center<-centers
   P$membership<-S
+  P$weight<-weight
+  P$use_rotation<-use_rotation
+  P$rotation<-rotation
   P$fn<-"NDA"
+  P$seed<-seed
   P$Call<-cl
-  class(P) <- "nda"
+  class(P) <- c("nda","list")
   return(P)
 }
 
